@@ -82,7 +82,7 @@ func InitializeImportCollector(
 		isc.cbCollectISCounts = cbCollectISCounts
 	}
 
-	if !isc.IsCreated() && isc.cbCollectISCounts != nil && isc.cbCollectScheduledCounts != nil {
+	if !isc.IsCreated() {
 		legacyregistry.MustRegister(&isc)
 		klog.V(4).Info("Image import controller metrics registered with prometherus")
 	}
@@ -130,6 +130,16 @@ func (isc *importStatusCollector) Collect(ch chan<- prometheus.Metric) {
 	pushErrorCounts("true", errorCounts, ch)
 }
 
+func (isc *importStatusCollector) ClearState() {
+	isc.createLock.Lock()
+	defer isc.createLock.Unlock()
+	isc.isCreated = false
+}
+
+func (isc *importStatusCollector) FQName() string {
+	return metricController
+}
+
 func pushSuccessCounts(scheduled string, counts ImportSuccessCounts, ch chan<- prometheus.Metric) {
 	for registry, count := range counts {
 		ch <- prometheus.MustNewConstMetric(
